Enum SystemHandle
pub enum SystemHandle<I = (), O = ()>where
I: SystemInput,{
Strong(Arc<StrongSystemHandle>),
Weak(SystemId<I, O>),
}Expand description
A maybe-strong handle to an entity acting as a registered system. Strong
handles are created by World::register_tracked_system or
World::register_tracked_boxed_system.
Strong handles provide automatic cleanup of registered systems once all clones
of the handle are dropped, while weak handles do not. However, the existence
of a strong handle does not prevent the registered system entity from being
despawned manually, like with World::unregister_system or
World::unregister_system_cached.
Cleanup
Registered system entities are cleaned up by the despawn_unused_registered_systems
system, which is automatically added to the default app by the bevy_app
crate when the “std” feature is enabled. If not using the default app, the
“std” feature, or bevy_app in general, consider running this system
yourself to ensure proper cleanup of registered systems.
Variants
Strong(Arc<StrongSystemHandle>)
A strong handle keeps the system entity alive as long as the handle (and any clones of it) exist, as long as the system entity isn’t manually despawned.
Weak(SystemId<I, O>)
A weak handle does not keep the system entity alive.
Implementations
impl<I, O> SystemHandle<I, O>where
I: SystemInput,
impl<I, O> SystemHandle<I, O>where
I: SystemInput,