Struct ExclusiveFunctionSystem
pub struct ExclusiveFunctionSystem<Marker, Out, F>where
F: ExclusiveSystemParamFunction<Marker>,{ /* private fields */ }Expand description
A function system that runs with exclusive World access.
You get this by calling IntoSystem::into_system on a function that only accepts
ExclusiveSystemParams.
ExclusiveFunctionSystem must be .initialized before they can be run.
Implementations
impl<Marker, Out, F> ExclusiveFunctionSystem<Marker, Out, F>where
F: ExclusiveSystemParamFunction<Marker>,
impl<Marker, Out, F> ExclusiveFunctionSystem<Marker, Out, F>where
F: ExclusiveSystemParamFunction<Marker>,
pub fn with_name(
self,
new_name: impl Into<Cow<'static, str>>,
) -> ExclusiveFunctionSystem<Marker, Out, F>
pub fn with_name( self, new_name: impl Into<Cow<'static, str>>, ) -> ExclusiveFunctionSystem<Marker, Out, F>
Return this system with a new name.
Useful to give closure systems more readable and unique names for debugging and tracing.