Struct In
pub struct In<In>(pub In);Expand description
Wrapper type to mark a SystemParam as an input.
Systems may take an optional input which they require to be passed to them when they
are being run. For FunctionSystems the input may be marked
with this In type, but only the first param of a function may be tagged as an input. This also
means a system can only have one or zero input parameters.
Examples
Here is a simple example of a system that takes a usize returning the square of it.
use bevy_ecs::prelude::*;
fn main() {
let mut square_system = IntoSystem::into_system(square);
let mut world = World::default();
square_system.initialize(&mut world);
assert_eq!(square_system.run(12, &mut world), 144);
}
fn square(In(input): In<usize>) -> usize {
input * input
}Tuple Fields
0: InTrait Implementations