Struct ParamBuilder
pub struct ParamBuilder;Expand description
A SystemParamBuilder for any SystemParam that uses its default initialization.
Example
fn my_system(res: Res<R>, param: MyParam, query: Query<&A>) {
// ...
}
let system = (
// A plain ParamBuilder can build any parameter type.
ParamBuilder,
// The `of::<P>()` method returns a `ParamBuilder`
// typed as `impl SystemParamBuilder<P>`.
ParamBuilder::of::<MyParam>(),
// The other factory methods return typed builders
// for common parameter types.
ParamBuilder::query::<&A>(),
)
.build_state(&mut world)
.build_system(my_system);Implementations
impl ParamBuilder
impl ParamBuilder
pub fn of<T>() -> impl SystemParamBuilder<T>where
T: SystemParam,
pub fn of<T>() -> impl SystemParamBuilder<T>where
T: SystemParam,
Creates a SystemParamBuilder for any SystemParam that uses its default initialization.
pub fn resource<'w, T>() -> impl SystemParamBuilder<Res<'w, T>>where
T: Resource,
pub fn resource<'w, T>() -> impl SystemParamBuilder<Res<'w, T>>where
T: Resource,
Helper method for reading a Resource as a param, equivalent to of::<Res<T>>()
pub fn resource_mut<'w, T>() -> impl SystemParamBuilder<ResMut<'w, T>>
pub fn resource_mut<'w, T>() -> impl SystemParamBuilder<ResMut<'w, T>>
Helper method for mutably accessing a Resource as a param, equivalent to of::<ResMut<T>>()
pub fn local<'s, T>() -> impl SystemParamBuilder<Local<'s, T>>
pub fn local<'s, T>() -> impl SystemParamBuilder<Local<'s, T>>
Helper method for adding a Local as a param, equivalent to of::<Local<T>>()
pub fn query<'w, 's, D>() -> impl SystemParamBuilder<Query<'w, 's, D>>where
D: QueryData + 'static,
pub fn query<'w, 's, D>() -> impl SystemParamBuilder<Query<'w, 's, D>>where
D: QueryData + 'static,
Helper method for adding a Query as a param, equivalent to of::<Query<D>>()
pub fn query_filtered<'w, 's, D, F>() -> impl SystemParamBuilder<Query<'w, 's, D, F>>where
D: QueryData + 'static,
F: QueryFilter + 'static,
pub fn query_filtered<'w, 's, D, F>() -> impl SystemParamBuilder<Query<'w, 's, D, F>>where
D: QueryData + 'static,
F: QueryFilter + 'static,
Helper method for adding a filtered Query as a param, equivalent to of::<Query<D, F>>()