Struct QueryParamBuilder
pub struct QueryParamBuilder<T>(/* private fields */);Expand description
A SystemParamBuilder for a Query.
This takes a closure accepting an &mut QueryBuilder and uses the builder to construct the query’s state.
This can be used to add additional filters,
or to configure the components available to FilteredEntityRef or FilteredEntityMut.
Example
let system = (QueryParamBuilder::new(|builder| {
builder.with::<Player>();
}),)
.build_state(&mut world)
.build_system(|query: Query<()>| {
for _ in &query {
// This only includes entities with a `Player` component.
}
});
// When collecting multiple builders into a `Vec`,
// use `new_box()` to erase the closure type.
let system = (vec![
QueryParamBuilder::new_box(|builder| {
builder.with::<Player>();
}),
QueryParamBuilder::new_box(|builder| {
builder.without::<Player>();
}),
],)
.build_state(&mut world)
.build_system(|query: Vec<Query<()>>| {});Implementations
impl<T> QueryParamBuilder<T>
impl<T> QueryParamBuilder<T>
pub fn new<D, F>(f: T) -> QueryParamBuilder<T>
pub fn new<D, F>(f: T) -> QueryParamBuilder<T>
Creates a SystemParamBuilder for a Query that accepts a callback to configure the QueryBuilder.
impl<'a, D, F> QueryParamBuilder<Box<dyn FnOnce(&mut QueryBuilder<'_, D, F>) + 'a>>where
D: QueryData,
F: QueryFilter,
impl<'a, D, F> QueryParamBuilder<Box<dyn FnOnce(&mut QueryBuilder<'_, D, F>) + 'a>>where
D: QueryData,
F: QueryFilter,
pub fn new_box(
f: impl FnOnce(&mut QueryBuilder<'_, D, F>) + 'a,
) -> QueryParamBuilder<Box<dyn FnOnce(&mut QueryBuilder<'_, D, F>) + 'a>>
pub fn new_box( f: impl FnOnce(&mut QueryBuilder<'_, D, F>) + 'a, ) -> QueryParamBuilder<Box<dyn FnOnce(&mut QueryBuilder<'_, D, F>) + 'a>>
Creates a SystemParamBuilder for a Query that accepts a callback to configure the QueryBuilder.
This boxes the callback so that it has a common type and can be put in a Vec.