Struct SystemMeta
pub struct SystemMeta { /* private fields */ }Expand description
The metadata of a System.
Implementations
impl SystemMeta
impl SystemMeta
pub fn name(&self) -> &DebugName
pub fn name(&self) -> &DebugName
Returns the system’s name
pub fn flags(&self) -> SystemStateFlags
pub fn flags(&self) -> SystemStateFlags
Returns the system’s state flags
pub fn set_name(&mut self, new_name: impl Into<Cow<'static, str>>)
pub fn set_name(&mut self, new_name: impl Into<Cow<'static, str>>)
Sets the name of this system.
Useful to give closure systems more readable and unique names for debugging and tracing.
pub fn get_last_run(&self) -> Tick
pub fn get_last_run(&self) -> Tick
Gets the last time this system was run.
pub fn set_last_run(&mut self, last_run: Tick)
pub fn set_last_run(&mut self, last_run: Tick)
Sets the last time this system was run.
pub fn set_non_send(&mut self)
pub fn set_non_send(&mut self)
Sets the system to be not Send.
This is irreversible.
pub fn has_deferred(&self) -> bool
pub fn has_deferred(&self) -> bool
Returns true if the system has deferred SystemParam’s
pub fn set_has_deferred(&mut self)
pub fn set_has_deferred(&mut self)
Marks the system as having deferred buffers like Commands
This lets the scheduler insert ApplyDeferred systems automatically.
pub fn set_exclusive(&mut self)
pub fn set_exclusive(&mut self)
Mark the system to run exclusively. i.e. no other systems will run at the same time.