SystemParamValidationError

Struct SystemParamValidationError 

pub struct SystemParamValidationError {
    pub skipped: bool,
    pub message: Cow<'static, str>,
    pub param: DebugName,
    pub field: Cow<'static, str>,
}
An error that occurs when a system parameter is not valid, used by system executors to determine what to do with a system.

Returned as an error from SystemParam::get_param, and handled using the unified error handling mechanisms defined in bevy_ecs::error.

Fields

skipped: bool

Whether the system should be skipped.

If false, the error should be handled. By default, this will result in a panic. See error for more information.

This is the default behavior, and is suitable for system params that should always be valid, either because sensible fallback behavior exists (like Query) or because failures in validation should be considered a bug in the user’s logic that must be immediately addressed (like Res).

If true, the system should be skipped. This is set by wrapping the system param in If, and indicates that the system is intended to only operate in certain application states.

message: Cow<'static, str>

A message describing the validation error.

param: DebugName

A string identifying the invalid parameter. This is usually the type name of the parameter.

field: Cow<'static, str>

A string identifying the field within a parameter using #[derive(SystemParam)]. This will be an empty string for other parameters.

This will be printed after param in the Display impl, and should include a :: prefix if non-empty.

Implementations



impl SystemParamValidationError

pub fn skipped<T>( message: impl Into<Cow<'static, str>>, ) -> SystemParamValidationError

Constructs a SystemParamValidationError that skips the system. The parameter name is initialized to the type name of T, so a SystemParam should usually pass Self.

pub fn invalid<T>( message: impl Into<Cow<'static, str>>, ) -> SystemParamValidationError

Constructs a SystemParamValidationError for an invalid parameter that should be treated as an error. The parameter name is initialized to the type name of T, so a SystemParam should usually pass Self.

pub fn new<T>( skipped: bool, message: impl Into<Cow<'static, str>>, field: impl Into<Cow<'static, str>>, ) -> SystemParamValidationError

Constructs a SystemParamValidationError for an invalid parameter. The parameter name is initialized to the type name of T, so a SystemParam should usually pass Self.