Struct ParamSetBuilder
pub struct ParamSetBuilder<T>(pub T);Expand description
A SystemParamBuilder for a ParamSet.
To build a ParamSet with a tuple of system parameters, pass a tuple of matching SystemParamBuilders.
To build a ParamSet with a Vec of system parameters, pass a Vec of matching SystemParamBuilders.
Examples
let system = (ParamSetBuilder((
QueryParamBuilder::new(|builder| {
builder.with::<Enemy>();
}),
QueryParamBuilder::new(|builder| {
builder.with::<Ally>();
}),
ParamBuilder,
)),)
.build_state(&mut world)
.build_system(buildable_system_with_tuple);
fn buildable_system_with_tuple(
mut set: ParamSet<(Query<&mut Health>, Query<&mut Health>, &World)>,
) {
// The first parameter is built from the first builder,
// so this will iterate over enemies.
for mut health in set.p0().iter_mut() {}
// And the second parameter is built from the second builder,
// so this will iterate over allies.
for mut health in set.p1().iter_mut() {}
// Parameters that don't need special building can use `ParamBuilder`.
let entities = set.p2().entities();
}
let system = (ParamSetBuilder(vec![
QueryParamBuilder::new_box(|builder| {
builder.with::<Enemy>();
}),
QueryParamBuilder::new_box(|builder| {
builder.with::<Ally>();
}),
]),)
.build_state(&mut world)
.build_system(buildable_system_with_vec);
fn buildable_system_with_vec(mut set: ParamSet<Vec<Query<&mut Health>>>) {
// As with tuples, the first parameter is built from the first builder,
// so this will iterate over enemies.
for mut health in set.get_mut(0).iter_mut() {}
// And the second parameter is built from the second builder,
// so this will iterate over allies.
for mut health in set.get_mut(1).iter_mut() {}
// You can iterate over the parameters either by index,
// or using the `for_each` method.
set.for_each(|mut query| for mut health in query.iter_mut() {});
}Tuple Fields
0: TTrait Implementations
impl<T> Clone for ParamSetBuilder<T>where
T: Clone,
impl<T> Clone for ParamSetBuilder<T>where
T: Clone,
fn clone(&self) -> ParamSetBuilder<T>
fn clone(&self) -> ParamSetBuilder<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T> Debug for ParamSetBuilder<T>where
T: Debug,
impl<T> Debug for ParamSetBuilder<T>where
T: Debug,
impl<T> Default for ParamSetBuilder<T>where
T: Default,
impl<T> Default for ParamSetBuilder<T>where
T: Default,
fn default() -> ParamSetBuilder<T>
fn default() -> ParamSetBuilder<T>
Returns the “default value” for a type. Read more
impl<'w, 's, P0, B0> SystemParamBuilder<ParamSet<'w, 's, (P0,)>> for ParamSetBuilder<(B0,)>where
P0: SystemParam,
B0: SystemParamBuilder<P0>,
impl<'w, 's, P0, B0> SystemParamBuilder<ParamSet<'w, 's, (P0,)>> for ParamSetBuilder<(B0,)>where
P0: SystemParam,
B0: SystemParamBuilder<P0>,
fn build(self, world: &mut World) -> <(P0,) as SystemParam>::State
fn build(self, world: &mut World) -> <(P0,) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, B0, B1> SystemParamBuilder<ParamSet<'w, 's, (P0, P1)>> for ParamSetBuilder<(B0, B1)>
impl<'w, 's, P0, P1, B0, B1> SystemParamBuilder<ParamSet<'w, 's, (P0, P1)>> for ParamSetBuilder<(B0, B1)>
fn build(self, world: &mut World) -> <(P0, P1) as SystemParam>::State
fn build(self, world: &mut World) -> <(P0, P1) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, P2, B0, B1, B2> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2)>> for ParamSetBuilder<(B0, B1, B2)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
impl<'w, 's, P0, P1, P2, B0, B1, B2> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2)>> for ParamSetBuilder<(B0, B1, B2)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
fn build(self, world: &mut World) -> <(P0, P1, P2) as SystemParam>::State
fn build(self, world: &mut World) -> <(P0, P1, P2) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, P2, P3, B0, B1, B2, B3> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3)>> for ParamSetBuilder<(B0, B1, B2, B3)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
impl<'w, 's, P0, P1, P2, P3, B0, B1, B2, B3> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3)>> for ParamSetBuilder<(B0, B1, B2, B3)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
fn build(self, world: &mut World) -> <(P0, P1, P2, P3) as SystemParam>::State
fn build(self, world: &mut World) -> <(P0, P1, P2, P3) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, P2, P3, P4, B0, B1, B2, B3, B4> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4)>> for ParamSetBuilder<(B0, B1, B2, B3, B4)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
impl<'w, 's, P0, P1, P2, P3, P4, B0, B1, B2, B3, B4> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4)>> for ParamSetBuilder<(B0, B1, B2, B3, B4)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
fn build(
self,
world: &mut World,
) -> <(P0, P1, P2, P3, P4) as SystemParam>::State
fn build( self, world: &mut World, ) -> <(P0, P1, P2, P3, P4) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, P2, P3, P4, P5, B0, B1, B2, B3, B4, B5> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5)>> for ParamSetBuilder<(B0, B1, B2, B3, B4, B5)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
P5: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
B5: SystemParamBuilder<P5>,
impl<'w, 's, P0, P1, P2, P3, P4, P5, B0, B1, B2, B3, B4, B5> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5)>> for ParamSetBuilder<(B0, B1, B2, B3, B4, B5)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
P5: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
B5: SystemParamBuilder<P5>,
fn build(
self,
world: &mut World,
) -> <(P0, P1, P2, P3, P4, P5) as SystemParam>::State
fn build( self, world: &mut World, ) -> <(P0, P1, P2, P3, P4, P5) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, P2, P3, P4, P5, P6, B0, B1, B2, B3, B4, B5, B6> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5, P6)>> for ParamSetBuilder<(B0, B1, B2, B3, B4, B5, B6)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
P5: SystemParam,
P6: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
B5: SystemParamBuilder<P5>,
B6: SystemParamBuilder<P6>,
impl<'w, 's, P0, P1, P2, P3, P4, P5, P6, B0, B1, B2, B3, B4, B5, B6> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5, P6)>> for ParamSetBuilder<(B0, B1, B2, B3, B4, B5, B6)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
P5: SystemParam,
P6: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
B5: SystemParamBuilder<P5>,
B6: SystemParamBuilder<P6>,
fn build(
self,
world: &mut World,
) -> <(P0, P1, P2, P3, P4, P5, P6) as SystemParam>::State
fn build( self, world: &mut World, ) -> <(P0, P1, P2, P3, P4, P5, P6) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P0, P1, P2, P3, P4, P5, P6, P7, B0, B1, B2, B3, B4, B5, B6, B7> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5, P6, P7)>> for ParamSetBuilder<(B0, B1, B2, B3, B4, B5, B6, B7)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
P5: SystemParam,
P6: SystemParam,
P7: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
B5: SystemParamBuilder<P5>,
B6: SystemParamBuilder<P6>,
B7: SystemParamBuilder<P7>,
impl<'w, 's, P0, P1, P2, P3, P4, P5, P6, P7, B0, B1, B2, B3, B4, B5, B6, B7> SystemParamBuilder<ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5, P6, P7)>> for ParamSetBuilder<(B0, B1, B2, B3, B4, B5, B6, B7)>where
P0: SystemParam,
P1: SystemParam,
P2: SystemParam,
P3: SystemParam,
P4: SystemParam,
P5: SystemParam,
P6: SystemParam,
P7: SystemParam,
B0: SystemParamBuilder<P0>,
B1: SystemParamBuilder<P1>,
B2: SystemParamBuilder<P2>,
B3: SystemParamBuilder<P3>,
B4: SystemParamBuilder<P4>,
B5: SystemParamBuilder<P5>,
B6: SystemParamBuilder<P6>,
B7: SystemParamBuilder<P7>,
fn build(
self,
world: &mut World,
) -> <(P0, P1, P2, P3, P4, P5, P6, P7) as SystemParam>::State
fn build( self, world: &mut World, ) -> <(P0, P1, P2, P3, P4, P5, P6, P7) as SystemParam>::State
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
impl<'w, 's, P, B> SystemParamBuilder<ParamSet<'w, 's, Vec<P>>> for ParamSetBuilder<Vec<B>>where
P: SystemParam,
B: SystemParamBuilder<P>,
impl<'w, 's, P, B> SystemParamBuilder<ParamSet<'w, 's, Vec<P>>> for ParamSetBuilder<Vec<B>>where
P: SystemParam,
B: SystemParamBuilder<P>,
fn build(self, world: &mut World) -> <Vec<P> as SystemParam>::State ⓘ
fn build(self, world: &mut World) -> <Vec<P> as SystemParam>::State ⓘ
Registers any
World access used by this SystemParam
and creates a new instance of this param’s State.fn build_state(self, world: &mut World) -> SystemState<P>
fn build_state(self, world: &mut World) -> SystemState<P>
Create a
SystemState from a SystemParamBuilder.
To create a system, call SystemState::build_system on the result.fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,
fn build_system<Marker, In, Out, Func>(
self,
func: Func,
) -> IntoBuilderSystem<Marker, In, Out, Func, Self>where
Self: 'static,
Func: SystemParamFunction<Marker, Param = P>,