Trait IntoObserverSystem
pub trait IntoObserverSystem<E, B, M, Out = ()>: Send + 'static{
type System: ObserverSystem<E, B, Out>;
// Required method
fn into_system(this: Self) -> Self::System;
}Expand description
Implemented for systems that convert into ObserverSystem.
Usage notes
This trait should only be used as a bound for trait implementations or as an
argument to a function. If an observer system needs to be returned from a
function or stored somewhere, use ObserverSystem instead of this trait.
Required Associated Types
type System: ObserverSystem<E, B, Out>
type System: ObserverSystem<E, B, Out>
The type of System that this instance converts into.
Required Methods
fn into_system(this: Self) -> Self::System
fn into_system(this: Self) -> Self::System
Turns this value into its corresponding System.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.